require 'stormwatch/workflows/base'

module Stormwatch
  module Workflows
    class CreateBoard < Base
      include Requirements[
        'storage.boards',
      ]

      def call(payload:)
        payload = Payload.new(payload)

        unless board = boards.create_board(payload.name)
          broadcast(:failure)
          return
        end

        broadcast(
          :success, 
          {
            uuid: board.uuid,
            name: board.name,
          }
        )
      end

      class Payload < Base::Payload
        attribute :name, String
      end

    end

    Registry.register(
      'create_board',
      -> {CreateBoard.new}
    )
  end
end
