require 'stormwatch/workflows/base'

module Stormwatch
  module Workflows
    class CreateBox < Base
      include Requirements[
        'storage.boards',
        'storage.boxes'
      ]

      def call(payload:)
        payload = Payload.new(payload)

        board = boards.find_board(payload.uuid)

        if board.nil?
          broadcast(:not_found)
          return
        end

        unless box = boxes.create_box(board.id, payload.content)
          broadcast(:not_created)
          return
        end

        broadcast(
          :success, 
          {
            uuid: box.uuid,
            content: box.content,
            board_uuid: board.uuid
          }
        )
      end

      class Payload < Base::Payload
        attribute :uuid, Types::String
        attribute :content, Types::String
      end

    end

    Registry.register(
      'create_box',
      -> {CreateBox.new}
    )
  end
end
