require 'stormwatch/workflows/base'

module Stormwatch
  module Workflows
    class UpdateBox < Base
      include Requirements[
        'storage.boxes'
      ]

      def call(payload:)
        payload = Payload.new(payload)
        box = boxes.find_box(payload.uuid)

        if box.nil?
          broadcast(:not_found)
          return
        end

        unless box = boxes.update_box(box.id, payload.content)
          broadcast(:not_updated)
          return
        end

        broadcast(
          :success, 
          {
            uuid: box.uuid,
            content: box.content,
            board_uuid: box.board.uuid
          }
        )
      end

      class Payload < Base::Payload
        attribute :uuid, Types::String
        attribute :content, Types::String
      end

    end

    Registry.register(
      'update_box',
      -> {UpdateBox.new}
    )
  end
end
